@@ -1,10 +1,10 @@
 use strict;
 use warnings;
-package Task::Kensho::Config;
-# git description: v0.37-23-g66003fc
-$Task::Kensho::Config::VERSION = '0.38';
+package Task::Kensho::Config; # git description: v0.38-48-gdb8e27c
 # ABSTRACT: A Glimpse at an Enlightened Perl: Config Modules
 
+our $VERSION = '0.39';
+
 __END__
 
 =pod
@@ -17,7 +17,7 @@ Task::Kensho::Config - A Glimpse at an Enlightened Perl: Config Modules
 
 =head1 VERSION
 
-version 0.38
+version 0.39
 
 =head1 SYNOPSIS
 
@@ -76,6 +76,10 @@ Load configuration from different file formats, transparently
 
 Generic Config Module
 
+=head3 L<JSON::MaybeXS>
+
+wrapper around the most current and fast JSON backends
+
 =head1 INSTALLING
 
 Since version 0.34, L<Task::Kensho> has made use of the C<optional_features> field
@@ -86,6 +90,11 @@ The C<cpanm> client requires interactive mode to be enabled for this to work:
 
     cpanm --interactive Task::Kensho::Config
 
+=head1 SEE ALSO
+
+L<http://www.enlightenedperl.org/>,
+L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>
+
 =head1 BUGS AND LIMITATIONS
 
 This list is by no means comprehensive of the "Good" Modules on CPAN.
@@ -97,25 +106,18 @@ starting place on the road to Enlightened Perl programming.
 Please report any bugs or feature requests to
 L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-=head1 SEE ALSO
+bugs may be submitted through L<https://github.com/EnlightenedPerlOrganisation/task-kensho/issues>.
 
-L<http://www.enlightenedperl.org/>,
-L<Perl::Dist::Strawberry|Perl::Dist::Strawberry>
+There is also an irc channel available for users of this distribution, at
+L<C<#epo> on C<irc.perl.org>|irc://irc.perl.org/#epo>.
 
 =head1 AUTHOR
 
 Chris Prather <chris@prather.org>
 
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2008 by Chris Prather.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =head1 CONTRIBUTORS
 
-=for stopwords Karen Etheridge Leo Lapworth Chris Nehren
+=for stopwords Karen Etheridge Leo Lapworth Chris Nehren Rick Leir
 
 =over 4
 
@@ -131,6 +133,17 @@ Leo Lapworth <leo@cuckoo.org>
 
 Chris Nehren <apeiron@cpan.org>
 
+=item *
+
+Rick Leir <rleir@leirtech.com>
+
 =back
 
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by Chris Prather.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
